#
# Conditional build:
%bcond_without	systemd		# without systemd support

%define		gitref	ab6ea89b11b1f1a8dcbfd7cfc29d65b3013f2702
%define		snap	20240324
%define		rel	2

Summary:	TV streaming server
Name:		tvheadend
# https://tvheadend.org/projects/tvheadend/wiki/Releases
Version:	4.3.0
Release:	0.%{snap}.%{rel}
License:	GPL v3
Group:		Applications/Multimedia
Source0:	https://github.com/tvheadend/tvheadend/archive/%{gitref}/%{name}-%{snap}.tar.gz
# Source0-md5:	551697c45195b4cee9178ef0e6ebb8e2
Source1:	%{name}.service
Source2:	%{name}.sysconfig
Source3:	%{name}.init
URL:		https://tvheadend.org/projects/tvheadend
BuildRequires:	avahi-devel
BuildRequires:	dbus-devel
BuildRequires:	ffmpeg-devel >= 3.0
BuildRequires:	gettext-tools
BuildRequires:	libdvbcsa-devel
BuildRequires:	libx264-devel
BuildRequires:	libx265-devel
BuildRequires:	openssl-devel
BuildRequires:	pcre2-8-devel
BuildRequires:	pkgconfig
BuildRequires:	python3-modules
BuildRequires:	rpmbuild(macros) >= 1.647
%{?with_systemd:BuildRequires:	systemd-devel}
BuildRequires:	uriparser-devel
BuildRequires:	zlib-devel
Requires(post):	sed >= 4.0
Requires(post,preun):	/sbin/chkconfig
%{?with_systemd:Requires(post,preun,postun):	systemd-units >= 38}
Requires(postun):	/usr/sbin/userdel
Requires(pre):	/bin/id
Requires(pre):	/usr/sbin/useradd
Requires:	setup
%{?with_systemd:Requires:	systemd-units >= 0.38}
Provides:	user(tvheadend)
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Tvheadend is a TV streaming server for Linux supporting DVB-S, DVB-S2,
DVB-C, DVB-T, ATSC, IPTV, and Analog video (V4L) as input sources.

%prep
%setup -q -n %{name}-%{gitref}

%{__sed} -i -e '1s,/usr/bin/env python3$,%{__python3},' lib/py/tvh/tv_meta_{tm,tv}db.py support/tvhmeta

%build
export CFLAGS="%{rpmcflags}"
export LDFLAGS="%{rpmldflags}"

# tvheadend uses a custom script, so %%configure cannot be used
# as not all options are supported
./configure \
	--cc="%{__cc}" \
	--release \
	--prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--mandir=%{_mandir} \
	--python=%{__python3} \
	--disable-dvbscan \
	--disable-ffmpeg_static \
	--disable-hdhomerun_static \
	%{!?with_systemd:--disable-libsystemd_daemon}

%{__make} V=1

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT%{_localstatedir}/lib/%{name}/.hts/%{name} \
	$RPM_BUILD_ROOT%{_localstatedir}/lib/%{name}/Videos \
	%{?with_systemd:$RPM_BUILD_ROOT%{systemdunitdir}} \
	$RPM_BUILD_ROOT/etc/{rc.d/init.d,sysconfig}

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT \
	V=1

%{?with_systemd:cp -p %{SOURCE1} $RPM_BUILD_ROOT%{systemdunitdir}/%{name}.service}
cp -p %{SOURCE2} $RPM_BUILD_ROOT/etc/sysconfig/%{name}
install -p %{SOURCE3} $RPM_BUILD_ROOT/etc/rc.d/init.d/%{name}

chmod +x $RPM_BUILD_ROOT%{_bindir}/%{name}

%clean
rm -rf $RPM_BUILD_ROOT

%pre
%useradd -u 20 -d %{_localstatedir}/lib/%{name} -g video -G usb -c "tvheadend User" tvheadend

%post
/sbin/chkconfig --add tvheadend
%service tvheadend reload "tvheadend"
%{?with_systemd:%systemd_post %{name}.service}

%preun
if [ "$1" = "0" ]; then
	%service tvheadend stop
	/sbin/chkconfig --del tvheadend
fi
%{?with_systemd:%systemd_preun %{name}.service}

%postun
if [ "$1" = "0" ]; then
	%userremove tvheadend
fi
%{?with_systemd:%systemd_reload}

%files
%defattr(644,root,root,755)
%doc docs
%attr(755,root,root) %{_bindir}/tvheadend
%attr(755,root,root) %{_bindir}/tvhmeta
%attr(755,root,root) %{_bindir}/tv_meta_tmdb.py
%attr(755,root,root) %{_bindir}/tv_meta_tvdb.py
%attr(754,root,root) /etc/rc.d/init.d/tvheadend
%config(noreplace) %verify(not md5 mtime size) /etc/sysconfig/%{name}
%{_mandir}/man1/%{name}.1*
%{_datadir}/%{name}
%{?with_systemd:%{systemdunitdir}/%{name}.service}

# home directory and config file
%dir %attr(755,tvheadend,root) %{_localstatedir}/lib/%{name}
%dir %attr(755,tvheadend,video) %{_localstatedir}/lib/%{name}/Videos
%dir %attr(750,tvheadend,video) %{_localstatedir}/lib/%{name}/.hts
%dir %attr(750,tvheadend,video) %{_localstatedir}/lib/%{name}/.hts/%{name}
%changelog
* Sun Apr 07 2024 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/tvheadend.git;a=log;h=master

* Sun Apr 07 2024 Jan Palus <atler@pld-linux.org> 2e64c45
- remove x32 patch (no longer seems necessary); rel 2

* Sat Apr 06 2024 Jan Palus <atler@pld-linux.org> 946db66
- up to 20240324 snap

* Sun Oct 22 2023 Jan Palus <atler@pld-linux.org> 9f36be8
- don't use field dropped in ffmpeg >= 6.0 only when building against such version

* Sat Oct 21 2023 Jan Rękorajski <baggins@pld-linux.org> 3767941
- fix building with ffmpeg 6
- package all files
= rel 2

* Wed Jul 26 2023 Jan Palus <atler@pld-linux.org> 7c84d27
- up to 20230719 snap

* Mon Mar 06 2023 Jan Palus <atler@pld-linux.org> 46048b4
- up to 20230306 snap

* Wed Jan 18 2023 Jan Palus <atler@pld-linux.org> 57597a2
- up to 20230117 snap

* Sat Sep 25 2021 Jan Rękorajski <baggins@pld-linux.org> 9b2bc5b
- relup.sh friendly release 2

* Mon Jun 07 2021 Jan Palus <atler@pld-linux.org> 4167357
- up to 4.3.0 snap

* Sat Dec 12 2020 Jan Palus <atler@pld-linux.org> c168192
- up to 4.2.8

* Sat Sep 15 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> a564ed8
- release 3 (by relup.sh)

* Sun Apr 29 2018 Jan Rękorajski <baggins@pld-linux.org> 8dc1827
- fix building with ffmpeg 4.0
- don't use -Werror, breaks on harmless warnings
- rel 2

* Sat Apr 16 2016 Jan Rękorajski <baggins@pld-linux.org> 3552479
- more bitness fixes

* Sat Apr 16 2016 Jan Rękorajski <baggins@pld-linux.org> 432988c
- fix int size issues

* Sat Apr 16 2016 Jan Rękorajski <baggins@pld-linux.org> 1b264c5
- updated to 4.0.8
- fixed building with ffmepg 3.x based on upstream https://tvheadend.org/projects/tvheadend/repository/revisions/c63371c8bf51928a6c965bdf17dd73555b7b9d54/diff/

* Thu Jul 16 2015 Jan Rękorajski <baggins@pld-linux.org> 42520cb
- fix time_t usage on x32

* Tue May 26 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> d32c34f
- more BR (ffmpeg, uriparser)

* Tue May 26 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 1eefc6e
- up to 4.0.2

* Mon Jan 20 2014 Jan Rękorajski <baggins@pld-linux.org> f4363db
- video group is provided by setup package
- rel 4

* Mon Jan 20 2014 Jan Rękorajski <baggins@pld-linux.org> 7c8d6e4
- release 3 (by relup.sh)

